@@ -17,14 +17,16 @@
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu).
 
 from core import models
-from core.translation import _t, new
-from colours import HTMLColorToRGBA
+from lib.reverse_translation import _t
+
 #---PIL
 def init():
     global Image
     import Image
+    global HTMLColorToRGBA
+    from lib.colors import HTMLColorToRGBA
 
-def canvas_size(image,new_size,centering,background_colour,opacity, 
+def canvas_size(image,new_size,centering,background_color,opacity, 
         old_size=None):
     #because of layer support photo size can be different from image layer size
     if old_size is None:
@@ -39,15 +41,15 @@ def canvas_size(image,new_size,centering,background_colour,opacity,
     x               = int(centering[0]*dx/100.0)
     y               = int(centering[1]*dy/100.0)
     #mode
-    if image.mode == 'RGBA':
-        background_colour = HTMLColorToRGBA(background_colour,opacity)
+    if image.mode in ['RGBA', 'LA', 'P']:
+        if image.mode != 'RGBA':
+            image = image.convert('RGBA')
+        background_color = HTMLColorToRGBA(background_color,opacity)
     if image.mode in ['RGB','RGBA']:
-        new_canvas  = Image.new(image.mode,new_size,background_colour)
+        new_canvas  = Image.new(image.mode,new_size,background_color)
     else:
-        new_canvas  = Image.new('RGB',new_size,background_colour)
-        new_canvas  = new_canvas.convert(image.mode)
+        new_canvas  = Image.new('RGB',new_size,background_color)
     new_canvas.paste(image,(x,y))
-    
     return new_canvas
 
 
@@ -60,28 +62,27 @@ class Action(models.Action):
     init        = staticmethod(init)
     pil         = staticmethod(canvas_size)
     version     = '0.1'
-    tags        = [_t('size'),_t('border')]
-    update_size = True
+    tags        = [_t('transform'), _t('size')]
     __doc__     = _t('Crop or expand the canvas without scaling')
     
     def interface(self,fields):
-        fields[_t('Width')]                  = self.PixelField('50%',
-                                                choices=self.PIXELS)
-        fields[_t('Height')]                 = self.PixelField('50%',
-                                                choices=self.PIXELS)
-        fields[_t('Resolution')]             = self.DpiField(choices=self.DPIS)
-        fields[_t('Align Horizontal')]       = self.SliderField(50,0,100)
-        fields[_t('Align Vertical')]         = self.SliderField(50,0,100)
-        fields[_t('Background Colour')]      = self.ColourField('#FFFFFF')
-        fields[_t('Opacity')]                = self.SliderField(0,0,100)
+        fields[_t('Canvas Width')] = self.PixelField('<max(width, height)> px',
+                                                    choices=self.PIXELS_X)
+        fields[_t('Canvas Height')] = self.PixelField('<max(width, height)> px',
+                                                    choices=self.PIXELS_Y)
+        fields[_t('Resolution')] = self.DpiField(choices=self.DPIS)
+        fields[_t('Align Horizontal')] = self.SliderField(50,0,100)
+        fields[_t('Align Vertical')] = self.SliderField(50,0,100)
+        fields[_t('Background Color')] = self.ColorField('#FFFFFF')
+        fields[_t('Opacity')] = self.SliderField(0,0,100)
         
     def values(self,info):
         #dpi
-        dpi         = self.get_field('Resolution',info)
+        dpi         = info['dpi'] = self.get_field('Resolution',info)
         #size
-        x0, y0      = info[new('Pil','Size')]
-        x1          = self.get_field_size('Width',info,x0,dpi)
-        y1          = self.get_field_size('Height',info,y0,dpi)
+        x0, y0      = info['size']
+        x1          = self.get_field_size('Canvas Width',info,x0,dpi)
+        y1          = self.get_field_size('Canvas Height',info,y0,dpi)
         new_size    = x1,y1
         #centering
         align_hor   = self.get_field('Align Horizontal', info)
@@ -91,7 +92,7 @@ class Action(models.Action):
             'old_size'      : (x0,y0),
             'new_size'      : new_size,
             'centering'     : (align_hor,align_ver),
-            'background_colour'   : self.get_field('Background Colour', info),
+            'background_color'   : self.get_field('Background Color', info),
             'opacity'       : int(
                                 (self.get_field('Opacity',info)/100.0)
                                 *255),
