@@ -22,7 +22,7 @@
 
 # Always import this:
 from core import models
-from core.translation import _t, new
+from lib.reverse_translation import _t
 
 #---PIL
 def init():
@@ -42,23 +42,21 @@ CROSS_POS               = (CROSS,CROSS,CROSS,CROSS)
 ROUNDED_POS             = (ROUNDED,ROUNDED,ROUNDED,ROUNDED)
 ROUNDED_RECTANGLE_ID    = 'rounded_rectangle_r%d_f%d_s%s_p%s'
 
-def round_image(image,cache={},radius=100,opacity=255,pos=ROUNDED_POS,
-        back_colour='#FFFFFF'):
+def round_image(image,cache={},round_all=True,rounding_type=None,radius=100,opacity=255,pos=ROUNDED_POS,
+        back_color='#FFFFFF'):
     if image.mode != 'RGBA':
         image = image.convert('RGBA')
-    mask    = create_rounded_rectangle(image.size,cache,radius,opacity,pos)
-    image.paste(Image.new('RGB',image.size,back_colour),(0,0),
+
+    if round_all:
+        pos = 4 * (rounding_type, )
+
+    mask = create_rounded_rectangle(image.size,cache,radius,opacity,pos)
+
+    image.paste(Image.new('RGB',image.size,back_color),(0,0),
         ImageChops.invert(mask))
     image.putalpha(mask)
     return image
 
-def create_corner(radius=100,opacity=255,factor=2):
-    corner  = Image.new('L',(factor*radius,factor*radius),0)
-    draw    = ImageDraw.Draw(corner)
-    draw.pieslice((0,0,2*factor*radius,2*factor*radius),180,270,fill=opacity)
-    corner  = corner.resize((radius,radius),Image.ANTIALIAS)
-    return corner
-
 def create_rounded_rectangle(size=(600,400),cache={},radius=100,opacity=255,
         pos=ROUNDED_POS):
     #rounded_rectangle
@@ -108,6 +106,13 @@ def create_rounded_rectangle(size=(600,400),cache={},radius=100,opacity=255,
         cache[rounded_rectangle_id] = rounded_rectangle
         return rounded_rectangle
 
+def create_corner(radius=100,opacity=255,factor=2):
+    corner  = Image.new('L',(factor*radius,factor*radius),0)
+    draw    = ImageDraw.Draw(corner)
+    draw.pieslice((0,0,2*factor*radius,2*factor*radius),180,270,fill=opacity)
+    corner  = corner.resize((radius,radius),Image.ANTIALIAS)
+    return corner
+
 #---Phatch
 class Action(models.Action):
     
@@ -118,12 +123,15 @@ class Action(models.Action):
     init        = staticmethod(init)
     pil         = staticmethod(round_image)
     version     = '0.1'
-    tags        = [_t('default'),_t('border')]
+    tags        = [_t('default'), _t('filter')]
     __doc__     = _t('Rounded or crossed corners')
     
     def interface(self,fields):
         fields[_t('Radius')]                = self.PixelField('2%',
                                                 choices=self.SMALL_PIXELS)
+        fields[_t('Same Method for All Corners')]             = self.BooleanField(True)
+        fields[_t('Method')]                = self.ChoiceField(CORNERS[0],
+                                                CORNERS)
         fields[_t('Top Left Corner')]       = self.ChoiceField(CORNERS[0],
                                                 CORNERS)
         fields[_t('Top Right Corner')]      = self.ChoiceField(CORNERS[0],
@@ -132,17 +140,41 @@ class Action(models.Action):
                                                 CORNERS)
         fields[_t('Bottom Right Corner')]   = self.ChoiceField(CORNERS[0],
                                                 CORNERS)
-        fields[_t('Background Colour')]     = self.ColourField('#FFFFFF')
+        fields[_t('Background Color')]      = self.ColorField('#FFFFFF')
         fields[_t('Opacity')]               = self.SliderField(100,1,100)
-                
+
+    def get_relevant_field_labels(self):
+        """If this method is present, Phatch will only show relevant
+        fields.
+
+        :returns: list of the field labels which are relevant
+        :rtype: list of strings
+
+        .. note::
+
+            It is very important that the list of labels has EXACTLY
+            the same order as defined in the interface method.
+        """
+        relevant = ['Radius', 'Same Method for All Corners']
+        if self.get_field_string('Same Method for All Corners') in ('yes','true'):
+            relevant.append('Method')
+        else:
+            relevant.extend(['Top Left Corner', 'Top Right Corner', 
+                'Bottom Left Corner', 'Bottom Right Corner'])
+        relevant.extend(['Background Color','Opacity'])
+        return relevant
+
     def values(self,info):
         #get info (always get this)
-        width, height   = info[new('Pil','Size')]
-        dpi             = info[new('dpi')]
-        
+        width, height   = info['size']
+        dpi             = info['dpi']
+
+        round_all       = self.get_field('Same Method for All Corners', info)
+        rounding_type   = self.get_field('Method', info)
+
         average         = (width+height/2)
         radius          = self.get_field_size('Radius',info,average,dpi)
-        opacity            = int((self.get_field('Opacity',info)/100.0)*255)
+        opacity         = int((self.get_field('Opacity',info)/100.0)*255)
         pos             = (
                             self.get_field('Top Left Corner',info),
                             self.get_field('Top Right Corner',info),
@@ -151,10 +183,12 @@ class Action(models.Action):
         )
         
         return {
+            'round_all'     : round_all,
+            'rounding_type' : rounding_type,
             'radius'        : radius,
-            'opacity'          : opacity,
+            'opacity'       : opacity,
             'pos'           : pos,
-            'back_colour'   : self.get_field('Background Colour',info)
+            'back_color'    : self.get_field('Background Color',info)
         }
 
     icon = \
