@@ -10,7 +10,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
@@ -19,7 +19,8 @@
 # Embedded icon is taken from www.openclipart.org (public domain)
 
 from core import models
-from core.translation import _t, new
+from lib.reverse_translation import _t
+from lib.imtools import has_transparency
 
 #---PIL
 def init():
@@ -27,29 +28,44 @@ def init():
     global Image, ImageChops, ImageFilter
     import Image, ImageChops, ImageFilter
 
-def drop_shadow(image, horizontal_offset=5, vertical_offset=5, background_colour=(255,255,255,0), 
-                shadow_colour=0x444444, border=8, shadow_blur=3, 
-                force_background_colour=False, cache={}):
-    """
-    Add a gaussian blur drop shadow to an image.  
+def drop_shadow(image, horizontal_offset=5, vertical_offset=5, background_color=(255,255,255,0),
+                shadow_color=0x444444, border=8, shadow_blur=3,
+                force_background_color=False, cache=None):
+    """Add a gaussian blur drop shadow to an image.
 
-    image           - The image to overlay on top of the shadow.
-    offset          - Offset of the shadow from the image as an (x,y) tuple.  
-                        Can be positive or negative.
-    background_colour     - Background colour behind the image.
-    shadow_colour   - Shadow colour (darkness).
-    border          - Width of the border around the image.  This must be wide
-                        enough to account for the blurring of the shadow.
-    shadow_blur      - Number of times to apply the filter.  More shadow_blur 
-                        produce a more blurred shadow, but increase processing 
-                        time.
+    :param image: The image to overlay on top of the shadow.
+    :param type: PIL Image
+    :param offset:
+
+        Offset of the shadow from the image as an (x,y) tuple.
+        Can be positive or negative.
+
+    :type offset: tuple of integers
+    :param background_color: Background color behind the image.
+    :param shadow_color: Shadow color (darkness).
+    :param border:
+
+        Width of the border around the image.  This must be wide
+        enough to account for the blurring of the shadow.
+
+    :param shadow_blur:
+
+        Number of times to apply the filter.  More shadow_blur
+        produce a more blurred shadow, but increase processing time.
     """
+    if cache is None:
+        cache   = {}
+
+    if has_transparency(image) and image.mode != 'RGBA':
+        # Make sure 'LA' and 'P' with trasparency are handled
+        image = image.convert('RGBA')
+
     #get info
     size        = image.size
     mode        = image.mode
-       
+
     back        = None
-            
+
     #assert image is RGBA
     if mode != 'RGBA':
         if mode != 'RGB':
@@ -57,13 +73,13 @@ def drop_shadow(image, horizontal_offset=5, vertical_offset=5, background_colour
             mode    = 'RGB'
         #create cache id
         id  = ''.join([str(x) for x in ['shadow_',size,horizontal_offset,vertical_offset,
-                    border, shadow_blur,background_colour,shadow_colour]])
-                    
+                    border, shadow_blur,background_color,shadow_color]])
+
         #look up in cache
         if cache.has_key(id):
             #retrieve from cache
             back, back_size = cache[id]
-            
+
     if back is None:
         #size of backdrop
         back_size       = (size[0] + abs(horizontal_offset) + 2*border,
@@ -74,19 +90,19 @@ def drop_shadow(image, horizontal_offset=5, vertical_offset=5, background_colour
             image_mask  = image.split()[-1]
             shadow      = Image.new('L',back_size,0)
         else:
-            image_mask  = Image.new(mode,size,shadow_colour)
-            shadow      = Image.new(mode,back_size,background_colour)
-            
+            image_mask  = Image.new(mode,size,shadow_color)
+            shadow      = Image.new(mode,back_size,background_color)
+
         shadow_left     = border + max(horizontal_offset, 0)
         shadow_top      = border + max(vertical_offset, 0)
-        shadow.paste(image_mask, (shadow_left, shadow_top, 
+        shadow.paste(image_mask, (shadow_left, shadow_top,
                                 shadow_left + size[0], shadow_top + size[1]))
         del image_mask #free up memory
-                            
+
         #blur shadow mask
 
-        #Apply the filter to blur the edges of the shadow.  Since a small 
-        #kernel is used, the filter must be applied repeatedly to get a decent 
+        #Apply the filter to blur the edges of the shadow.  Since a small
+        #kernel is used, the filter must be applied repeatedly to get a decent
         #blur.
         n   = 0
         while n < shadow_blur:
@@ -95,32 +111,32 @@ def drop_shadow(image, horizontal_offset=5, vertical_offset=5, background_colour
 
         #create back
         if mode == 'RGBA':
-            back  = Image.new('RGBA',back_size,shadow_colour)
+            back  = Image.new('RGBA',back_size,shadow_color)
             back.putalpha(shadow)
             del shadow #free up memory
         else:
             back        = shadow
             cache[id]   = back, back_size
 
-    #Paste the input image onto the shadow backdrop  
+    #Paste the input image onto the shadow backdrop
     image_left  = border - min(horizontal_offset, 0)
     image_top   = border - min(vertical_offset, 0)
     if mode == 'RGBA':
         back.paste(image, (image_left, image_top),image)
-        if force_background_colour:
+        if force_background_color:
             mask    = back.split()[-1]
-            back.paste(Image.new('RGB',back.size,background_colour),(0,0),
+            back.paste(Image.new('RGB',back.size,background_color),(0,0),
                 ImageChops.invert(mask))
             back.putalpha(mask)
     else:
         back.paste(image, (image_left, image_top))
-    
+
     return back
 
 #---Phatch
 class Action(models.Action):
     """Drops shadow"""
-    
+
     label       = _t('Shadow')
     author      = 'Stani'
     email       = 'spe.stani.be@gmail.com'
@@ -128,10 +144,9 @@ class Action(models.Action):
     init        = staticmethod(init)
     pil         = staticmethod(drop_shadow)
     version     = '0.1'
-    tags        = [_t('default'),_('border')]
-    update_size = True
+    tags        = [_t('default'), _t('filter')]
     __doc__     = _t('Drops a blurred shadow under a photo')
-    
+
     def interface(self,fields):
         fields[_t('Horizontal Offset')]        = self.PixelField('2%',
                                                 choices=self.SMALL_PIXELS)
@@ -140,20 +155,20 @@ class Action(models.Action):
         fields[_t('Border')]                   = self.PixelField('4%',
             choices=[str(int(x)*2) for x in self.SMALL_PIXELS])
         fields[_t('Shadow Blur')]              = self.SliderField(3,1,20)
-        fields[_t('Background Colour')]        = self.ColourField('#FFFFFF')
-        fields[_t('Shadow Colour')]            = self.ColourField('#444444')
-        fields[_t('Force Background Colour')]  = self.BooleanField(True)
- 
+        fields[_t('Background Color')]        = self.ColorField('#FFFFFF')
+        fields[_t('Shadow Color')]            = self.ColorField('#444444')
+        fields[_t('Force Background Color')]  = self.BooleanField(True)
+
     def values(self,info):
         #pixel fields
-        x, y        = info[new('Pil','Size')]
-        return super(Action,self).values(info, 
+        x, y        = info['size']
+        return super(Action,self).values(info,
             pixel_fields={
-                'Horizontal Offset' : x, 
+                'Horizontal Offset' : x,
                 'Vertical Offset'   : y,
                 'Border'            : (x+y)/2,
             })
-        
+
     icon = \
 'x\xda\x01\xb3\rL\xf2\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
 \x00\x000\x08\x06\x00\x00\x00W\x02\xf9\x87\x00\x00\x00\x04sBIT\x08\x08\x08\
