@@ -10,18 +10,27 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 
+try:
+    _
+except NameError:
+    _ = unicode
+
 import os, sys
 from data import license
 from data.info import INFO
-from translation import _t
-from config import USER_PATH, APP_USER_PATH, USER_ACTIONS_PATH,\
-    USER_MASKS_PATH, USER_WATERMARKS_PATH
+from lib.reverse_translation import _t
+from config import USER_PATH, USER_DATA_PATH, USER_CONFIG_PATH,\
+    USER_CACHE_PATH, USER_ACTIONLISTS_PATH, USER_ACTIONS_PATH,\
+    USER_BIN_PATH, USER_FONTS_PATH, USER_HIGHLIGHTS_PATH, \
+    USER_LOG_PATH, USER_MASKS_PATH, USER_SETTINGS_PATH, \
+    USER_WATERMARKS_PATH
 
 #---description
+DESKTOP_ENTRY_COMMENT   = _('Easily batch process images and edit metadata')
 DESCRIPTION             = _('Photo Batch Processor')
 LICENSE                 = license.GPL
 CONTACT                 = '%(author)s <%(author_email)s>'%INFO
@@ -62,18 +71,13 @@ if hasattr(sys,"frozen"):
     FILE    = sys.argv[0]
 else:
     FILE    = __file__
-PATH            = os.path.dirname(os.path.dirname(FILE))
+PATH                = os.path.dirname(os.path.dirname(FILE))
+PHATCH_ACTIONS_PATH = os.path.join(PATH,'actions')
 
-PATH_DELIMITER  = ';'
-ACTIONS_PATH    = os.path.join(PATH,'actions')
-USER_ACTIONLISTS_PATH   = os.path.join(APP_USER_PATH,'actionlists')
-USER_FONTS_PATH         = os.path.join(APP_USER_PATH,'fonts')
-SETTINGS_PATH           = os.path.join(APP_USER_PATH,'settings.cPickle')
-ERROR_LOG_PATH          = os.path.join(APP_USER_PATH,'error_log.txt')
-PREVIEW_PATH            = os.path.join(APP_USER_PATH,'preview')
+PATH_DELIMITER          = ';'
 
 LABEL_PHATCH_ACTIONLIST = '%s %s %%s...'%(INFO['name'],_('with'))
-LABEL_PHATCH_RECENT     = INFO['name']+' '+_('Recent')
+LABEL_PHATCH_RECENT     = _('%s Recent')%INFO['name']
 LABEL_PHATCH_INSPECTOR  = _('Image Inspector')
 
 INTEGRATE_PHATCH_ACTIONLIST = _("Associate Images with Action List in %s...")
@@ -94,7 +98,7 @@ else:
     COMMAND_PATH            = 'phatch'
     COMMAND_ARGUMENTS_PREFIX= ''
     COMMAND_FILE            = '%F'
-    
+
 #xubuntu doesn't handle %U
 COMMAND_ARGUMENTS           = {
                                 'DROP'      : '-d "%s"',
@@ -109,11 +113,11 @@ for key, value in COMMAND_ARGUMENTS.items():
         else:
             new_value           += ' '+COMMAND_FILE
     COMMAND_ARGUMENTS[key]  = new_value
-    
+
 COMMAND                     = {}
 for key, value in COMMAND_ARGUMENTS.items():
     COMMAND[key]            = COMMAND_PATH+' '+COMMAND_ARGUMENTS[key]
-    
+
 ##COMMAND_DROP            = 'phatch -d "%s" %%F'
 ##COMMAND_RECENT          = 'phatch -d recent %F'
 ##COMMAND_INSPECTOR       = 'phatch -n %F'
