@@ -10,46 +10,47 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
 
-import re
+# Follows PEP8
 
-import regex
-from unicoding import ensure_unicode
+from lib.safe import RE_EXPR, RE_VAR
+from lib.reverse_translation import _t, _r
+from lib.unicoding import ensure_unicode
 
 REVERSE = {}
-DOT     = '.'
 
-def new(*x):
-    return 'new'+DOT+DOT.join(x)
-
-def _to_english(match):
-    return '<%s>'%_r(match.group(1))
 
 def to_english(x):
-    _x  = _r(ensure_unicode(x))
+    _x = _r(ensure_unicode(x))
     if x != _x:
         return _x
-    return regex.VARIABLE.sub(_to_english,x)
+    return RE_EXPR.sub(_expr_to_english, x)
+
+
+def _expr_to_english(match):
+    """Translates variables within an expression to english."""
+    return '<%s>'%(RE_VAR.sub(_var_to_english, match.group(1)))
+
+
+def _var_to_english(match):
+    return _r(match.group('var'))+match.group('attr')
 
-def _to_local(match):
-    return '<%s>'%_(match.group(1))
 
 def to_local(x):
-    _x  = _(x)
+    _x = _(x)
     if x != _x:
         return _x
-    return regex.VARIABLE.sub(_to_local,x)
-
-def _t(phrase):
-    REVERSE[_(phrase)]    = phrase
-    return phrase
-        
-def _r(phrase):
-    return REVERSE.get(phrase,phrase)
+    return RE_EXPR.sub(_expr_to_local, x)
 
 
+def _expr_to_local(match):
+    return '<%s>'%(RE_VAR.sub(_var_to_local, match.group(1)))
+
+
+def _var_to_local(match):
+    return _(match.group('var'))+match.group('attr')
