@@ -22,7 +22,7 @@
 # - License: GPL
 
 import wx
-import graphics
+from lib.pyWx import graphics
 
 class Provider(wx.ArtProvider):
     def CreateBitmap(self,artid,client,size):
