@@ -12,11 +12,12 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 #
 # Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
+import os
 import sys
 import wx
 from core import ct
@@ -26,10 +27,10 @@ ID_droplet = wx.ID_FORWARD
 
 def install_frame(frame):
     try:
-        droplet  = import_module('droplet',ct.PLATFORM)
+        droplet  = import_module('droplet',ct.PLATFORM)#os.path.join('lib',ct.PLATFORM))
     except:
         droplet  = None
-    if droplet: 
+    if droplet:
         droplet.install(frame)
     else:
-        pass
\ No newline at end of file
+        pass
