@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import wx
-from treeEdit import TreeMixin
+from lib.pyWx.treeEdit import TreeMixin
 
 class Tree(TreeMixin,wx.TreeCtrl):
     
@@ -44,6 +44,8 @@ class Frame(wx.Frame):
         self.menu_file.AppendItem(self.menu_file_new)
         self.menu_file_open = wx.MenuItem(self.menu_file, wx.ID_OPEN, _("&Open...\tCtrl-O"), _("Opens an actions list"), wx.ITEM_NORMAL)
         self.menu_file.AppendItem(self.menu_file_open)
+        self.menu_file_open_library = wx.MenuItem(self.menu_file, wx.ID_PREVIEW_GOTO, _("Open &Library...\tCtrl-Shift-O"), _("Opens a ready-made actionlist from the library"), wx.ITEM_NORMAL)
+        self.menu_file.AppendItem(self.menu_file_open_library)
         self.menu_file_save = wx.MenuItem(self.menu_file, wx.ID_SAVE, _("&Save\tCtrl-S"), _("Saves an action list"), wx.ITEM_NORMAL)
         self.menu_file.AppendItem(self.menu_file_save)
         self.menu_file_save_as = wx.MenuItem(self.menu_file, wx.ID_SAVEAS, _("Save &As...\tCtrl-Shift-S"), _("Saves an action list as"), wx.ITEM_NORMAL)
@@ -56,11 +58,11 @@ class Frame(wx.Frame):
         menu_file_export.AppendItem(self.menu_file_export_recent_to_clipboard)
         self.menu_file_export_inspector_to_clipboard = wx.MenuItem(menu_file_export, wx.NewId(), _("Copy Image I&nspector as Command to Clipboard"), _("Paste this command in a launcher"), wx.ITEM_NORMAL)
         menu_file_export.AppendItem(self.menu_file_export_inspector_to_clipboard)
-        self.menu_file.AppendMenu(wx.ID_FORWARD, _("&Export..."), menu_file_export, "")
+        self.menu_file.AppendMenu(wx.ID_FORWARD, _("&Export"), menu_file_export, "")
         self.menu_file.AppendSeparator()
         self.menu_file_quit = wx.MenuItem(self.menu_file, wx.ID_EXIT, _("&Quit\tCtrl-Q"), _("Quit the application."), wx.ITEM_NORMAL)
         self.menu_file.AppendItem(self.menu_file_quit)
-        self.frame_menubar.Append(self.menu_file, _("&File"))
+        self.frame_menubar.Append(self.menu_file, _("&Action List"))
         self.menu_edit = wx.Menu()
         self.menu_edit_add = wx.MenuItem(self.menu_edit, wx.ID_ADD, _("&Add...\tCtrl-+"), _("Add an action"), wx.ITEM_NORMAL)
         self.menu_edit.AppendItem(self.menu_edit_add)
@@ -87,21 +89,36 @@ class Frame(wx.Frame):
         self.menu_view.AppendItem(self.menu_view_expand_all)
         self.menu_view_collapse_all = wx.MenuItem(self.menu_view, wx.ID_JUSTIFY_FILL, _("&Collapse All\tCtrl-Shift-E"), _("Show only the labels of the actions."), wx.ITEM_NORMAL)
         self.menu_view.AppendItem(self.menu_view_collapse_all)
+        self.menu_view_collapse_automatic = wx.MenuItem(self.menu_view, wx.ID_NOTOALL, _("&Collapse Automatically"), _("Expanding one action collapses the others."), wx.ITEM_CHECK)
+        self.menu_view.AppendItem(self.menu_view_collapse_automatic)
         self.frame_menubar.Append(self.menu_view, _("&View"))
         self.menu_tools = wx.Menu()
         self.menu_tools_execute = wx.MenuItem(self.menu_tools, wx.ID_OK, _("&Execute...\tCtrl-Return"), _("Execute the action list"), wx.ITEM_NORMAL)
         self.menu_tools.AppendItem(self.menu_tools_execute)
+        self.menu_tools_safe = wx.MenuItem(self.menu_tools, wx.ID_YESTOALL, _("&Safe Mode (recommended)"), _("Allow Geek action and unsafe expressions"), wx.ITEM_CHECK)
+        self.menu_tools.AppendItem(self.menu_tools_safe)
         self.menu_tools.AppendSeparator()
-        self.menu_tools_image_inspector = wx.MenuItem(self.menu_tools, wx.ID_PROPERTIES, _("&Image Inspector (exif)\tCtrl-Space"), _("Look up exif and iptc tags"), wx.ITEM_NORMAL)
+        self.menu_tools_image_inspector = wx.MenuItem(self.menu_tools, wx.ID_FIND, _("&Image Inspector (exif)\tCtrl-I"), _("Look up exif and iptc tags"), wx.ITEM_NORMAL)
         self.menu_tools.AppendItem(self.menu_tools_image_inspector)
+        menu_tools_browse_library = wx.Menu()
+        self.menu_tools_browse_library_user = wx.MenuItem(menu_tools_browse_library, wx.NewId(), _("&User"), _("Browse action lists, masks, highlights and fonts"), wx.ITEM_NORMAL)
+        menu_tools_browse_library.AppendItem(self.menu_tools_browse_library_user)
+        self.menu_tools_browse_library_phatch = wx.MenuItem(menu_tools_browse_library, wx.NewId(), _("&Phatch"), _("Browse action lists, masks, highlights and fonts"), wx.ITEM_NORMAL)
+        menu_tools_browse_library.AppendItem(self.menu_tools_browse_library_phatch)
+        self.menu_tools.AppendMenu(wx.ID_MORE, _("&Browse Library"), menu_tools_browse_library, "")
         self.menu_tools.AppendSeparator()
+        self.menu_tools_show_report = wx.MenuItem(self.menu_tools, wx.ID_PROPERTIES, _("Show &Report...\tCtrl+R"), _("Show report of processed images"), wx.ITEM_NORMAL)
+        self.menu_tools.AppendItem(self.menu_tools_show_report)
         self.menu_tools_show_log = wx.MenuItem(self.menu_tools, wx.ID_ZOOM_IN, _("Show &Log...\tCtrl-L"), _("Show log file"), wx.ITEM_NORMAL)
         self.menu_tools.AppendItem(self.menu_tools_show_log)
-        self.menu_tools_python_shell = wx.MenuItem(self.menu_tools, wx.ID_DUPLICATE, _("&Python Shell...\tCtrl-P"), _("Open a python shell for introspection"), wx.ITEM_CHECK)
-        self.menu_tools.AppendItem(self.menu_tools_python_shell)
+        self.menu_tools.AppendSeparator()
+        menu_tools_update = wx.Menu()
+        self.menu_tools_update_fonts = wx.MenuItem(menu_tools_update, wx.NewId(), _("&Fonts"), _("Scan for new fonts on your system"), wx.ITEM_NORMAL)
+        menu_tools_update.AppendItem(self.menu_tools_update_fonts)
+        self.menu_tools.AppendMenu(wx.NewId(), _("&Update"), menu_tools_update, "")
         self.frame_menubar.Append(self.menu_tools, _("&Tools"))
         self.menu_help = wx.Menu()
-        self.menu_help_website = wx.MenuItem(self.menu_help, wx.ID_HOME, _("Web&site...\tCtrl-I"), _("Go to the Phatch homepage."), wx.ITEM_NORMAL)
+        self.menu_help_website = wx.MenuItem(self.menu_help, wx.ID_HOME, _("&Website...\tCtrl-W"), _("Go to the Phatch homepage."), wx.ITEM_NORMAL)
         self.menu_help.AppendItem(self.menu_help_website)
         self.menu_help_documentation = wx.MenuItem(self.menu_help, wx.ID_HELP, _("&Documentation...\tCtrl-M"), _("Go to the Phatch documentation."), wx.ITEM_NORMAL)
         self.menu_help.AppendItem(self.menu_help_documentation)
@@ -112,7 +129,7 @@ class Frame(wx.Frame):
         self.menu_help.AppendItem(self.menu_help_translate)
         self.menu_help_bug = wx.MenuItem(self.menu_help, wx.ID_NO, _("&Report a Bug...\tCtrl-B"), _("Report a bug on launchpad."), wx.ITEM_NORMAL)
         self.menu_help.AppendItem(self.menu_help_bug)
-        self.menu_help_plugin = wx.MenuItem(self.menu_help, wx.ID_INDEX, _("&Write Action Plugin...\tCtrl-W"), _("Write a new action plugin for Phatch with PIL."), wx.ITEM_NORMAL)
+        self.menu_help_plugin = wx.MenuItem(self.menu_help, wx.ID_INDEX, _("De&veloper Documentation...\tCtrl-P"), _("Learn to develop Phatch with Python and PIL."), wx.ITEM_NORMAL)
         self.menu_help.AppendItem(self.menu_help_plugin)
         self.menu_help.AppendSeparator()
         self.menu_help_about = wx.MenuItem(self.menu_help, wx.ID_ABOUT, _("&About Phatch...\tCtrl-Shift-A"), _("Displays information about this application."), wx.ITEM_NORMAL)
@@ -130,6 +147,7 @@ class Frame(wx.Frame):
 
         self.Bind(wx.EVT_MENU, self.on_menu_file_new, self.menu_file_new)
         self.Bind(wx.EVT_MENU, self.on_menu_file_open, self.menu_file_open)
+        self.Bind(wx.EVT_MENU, self.on_menu_file_open_library, self.menu_file_open_library)
         self.Bind(wx.EVT_MENU, self.on_menu_file_save, self.menu_file_save)
         self.Bind(wx.EVT_MENU, self.on_menu_file_save_as, self.menu_file_save_as)
         self.Bind(wx.EVT_MENU, self.on_menu_file_export_actionlist_to_clipboard, self.menu_file_export_actionlist_to_clipboard)
@@ -146,10 +164,15 @@ class Frame(wx.Frame):
         self.Bind(wx.EVT_MENU, self.on_menu_view_description, self.menu_view_description)
         self.Bind(wx.EVT_MENU, self.on_menu_view_expand_all, self.menu_view_expand_all)
         self.Bind(wx.EVT_MENU, self.on_menu_view_collapse_all, self.menu_view_collapse_all)
+        self.Bind(wx.EVT_MENU, self.on_menu_view_collapse_automatic, self.menu_view_collapse_automatic)
         self.Bind(wx.EVT_MENU, self.on_menu_tools_execute, self.menu_tools_execute)
+        self.Bind(wx.EVT_MENU, self.on_menu_tools_safe, self.menu_tools_safe)
         self.Bind(wx.EVT_MENU, self.on_menu_tools_image_inspector, self.menu_tools_image_inspector)
+        self.Bind(wx.EVT_MENU, self.on_menu_tools_browse_library_user, self.menu_tools_browse_library_user)
+        self.Bind(wx.EVT_MENU, self.on_menu_tools_browse_library_phatch, self.menu_tools_browse_library_phatch)
+        self.Bind(wx.EVT_MENU, self.on_menu_tools_show_report, self.menu_tools_show_report)
         self.Bind(wx.EVT_MENU, self.on_menu_tools_show_log, self.menu_tools_show_log)
-        self.Bind(wx.EVT_MENU, self.on_menu_tools_python_shell, self.menu_tools_python_shell)
+        self.Bind(wx.EVT_MENU, self.on_menu_tools_update_fonts, self.menu_tools_update_fonts)
         self.Bind(wx.EVT_MENU, self.on_menu_help_website, self.menu_help_website)
         self.Bind(wx.EVT_MENU, self.on_menu_help_documentation, self.menu_help_documentation)
         self.Bind(wx.EVT_MENU, self.on_menu_help_forum, self.menu_help_forum)
@@ -315,6 +338,46 @@ class Frame(wx.Frame):
         print "Event handler `on_menu_file_export_inspector_to_clipboard' not implemented"
         event.Skip()
 
+    def on_menu_tools_browse_user_library(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_tools_browse_user_library' not implemented"
+        event.Skip()
+
+    def on_menu_tools_browse_system_library(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_tools_browse_system_library' not implemented"
+        event.Skip()
+
+    def on_menu_tools_browse_library_user(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_tools_browse_library_user' not implemented"
+        event.Skip()
+
+    def on_menu_tools_browse_library_phatch(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_tools_browse_library_phatch' not implemented"
+        event.Skip()
+
+    def on_menu_tools_show_report(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_tools_show_report' not implemented"
+        event.Skip()
+
+    def on_menu_tools_update_fonts(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_tools_update_fonts' not implemented"
+        event.Skip()
+
+    def on_menu_tools_safe(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_tools_safe' not implemented"
+        event.Skip()
+
+    def on_menu_file_open_library(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_file_open_library' not implemented"
+        event.Skip()
+
+    def on_menu_collapse_automatic(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_collapse_automatic' not implemented"
+        event.Skip()
+
+    def on_menu_view_collapse_automatic(self, event): # wxGlade: Frame.<event_handler>
+        print "Event handler `on_menu_view_collapse_automatic' not implemented"
+        event.Skip()
+
 # end of class Frame
 
 
